==========
catechin
==========

A tool to inspect ROS package configuration

Installation
==============

::

    pip install catechin

Usage
=====

::

    roscd <your package>
    catechin

Author
=======

Yuki Furuta <furushchev@jsk.imi.i.u-tokyo.ac.jp>

